info = {
    "name": "nmg",
    "date_order": "DMY",
    "january": [
        "ng1",
        "ngwɛn matáhra"
    ],
    "february": [
        "ng2",
        "ngwɛn ńmba"
    ],
    "march": [
        "ng3",
        "ngwɛn ńlal"
    ],
    "april": [
        "ng4",
        "ngwɛn ńna"
    ],
    "may": [
        "ng5",
        "ngwɛn ńtan"
    ],
    "june": [
        "ng6",
        "ngwɛn ńtuó"
    ],
    "july": [
        "ng7",
        "ngwɛn hɛmbuɛrí"
    ],
    "august": [
        "ng8",
        "ngwɛn lɔmbi"
    ],
    "september": [
        "ng9",
        "ngwɛn rɛbvuâ"
    ],
    "october": [
        "ng10",
        "ngwɛn wum"
    ],
    "november": [
        "ng11",
        "ngwɛn wum navǔr"
    ],
    "december": [
        "kris",
        "krísimin"
    ],
    "monday": [
        "mɔ́n",
        "mɔ́ndɔ"
    ],
    "tuesday": [
        "smb",
        "sɔ́ndɔ mafú mába"
    ],
    "wednesday": [
        "sml",
        "sɔ́ndɔ mafú málal"
    ],
    "thursday": [
        "smn",
        "sɔ́ndɔ mafú mána"
    ],
    "friday": [
        "mabágá má sukul",
        "mbs"
    ],
    "saturday": [
        "sas",
        "sásadi"
    ],
    "sunday": [
        "sɔ́n",
        "sɔ́ndɔ"
    ],
    "am": [
        "maná"
    ],
    "pm": [
        "kugú"
    ],
    "year": [
        "mbvu"
    ],
    "month": [
        "ngwɛn"
    ],
    "week": [
        "sɔ́ndɔ"
    ],
    "day": [
        "duö"
    ],
    "hour": [
        "wulā"
    ],
    "minute": [
        "mpálâ"
    ],
    "second": [
        "nyiɛl"
    ],
    "relative-type": {
        "0 day ago": [
            "dɔl"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "nakugú"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "namáná"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
