info = {
    "name": "ks",
    "date_order": "MDY",
    "january": [
        "جنؤری"
    ],
    "february": [
        "فرؤری"
    ],
    "march": [
        "مارٕچ"
    ],
    "april": [
        "اپریل"
    ],
    "may": [
        "میٔ"
    ],
    "june": [
        "جوٗن"
    ],
    "july": [
        "جوٗلایی"
    ],
    "august": [
        "اگست"
    ],
    "september": [
        "ستمبر"
    ],
    "october": [
        "اکتوٗبر"
    ],
    "november": [
        "نومبر"
    ],
    "december": [
        "دسمبر"
    ],
    "monday": [
        "ژٔنٛدرٕروار",
        "ژٔنٛدٕروار"
    ],
    "tuesday": [
        "بوٚموار"
    ],
    "wednesday": [
        "بودوار"
    ],
    "thursday": [
        "برٛٮ۪سوار"
    ],
    "friday": [
        "جُمہ"
    ],
    "saturday": [
        "بٹوار"
    ],
    "sunday": [
        "آتھوار",
        "اَتھوار"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ؤری"
    ],
    "month": [
        "رٮ۪تھ"
    ],
    "week": [
        "ہفتہٕ"
    ],
    "day": [
        "دۄہ"
    ],
    "hour": [
        "گٲنٛٹہٕ"
    ],
    "minute": [
        "مِنَٹ"
    ],
    "second": [
        "سٮ۪کَنڑ"
    ],
    "relative-type": {
        "0 day ago": [
            "اَز"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "راتھ"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "پگاہ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
