info = {
    "name": "qu",
    "date_order": "DMY",
    "january": [
        "qul",
        "qulla puquy"
    ],
    "february": [
        "hat",
        "hatun puquy"
    ],
    "march": [
        "pau",
        "pauqar waray"
    ],
    "april": [
        "ayr",
        "ayriwa"
    ],
    "may": [
        "aym",
        "aymuray"
    ],
    "june": [
        "int",
        "inti raymi"
    ],
    "july": [
        "ant",
        "anta sitwa"
    ],
    "august": [
        "qha",
        "qhapaq sitwa"
    ],
    "september": [
        "uma",
        "uma raymi"
    ],
    "october": [
        "kan",
        "kantaray"
    ],
    "november": [
        "aya",
        "ayamarq'a"
    ],
    "december": [
        "kap",
        "kapaq raymi"
    ],
    "monday": [
        "lun",
        "lunes"
    ],
    "tuesday": [
        "mar",
        "martes"
    ],
    "wednesday": [
        "mié",
        "miércoles"
    ],
    "thursday": [
        "jue",
        "jueves"
    ],
    "friday": [
        "vie",
        "viernes"
    ],
    "saturday": [
        "sab",
        "sábado"
    ],
    "sunday": [
        "dom",
        "domingo"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "qu-BO": {
            "name": "qu-BO"
        },
        "qu-EC": {
            "name": "qu-EC"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
