info = {
    "name": "ewo",
    "date_order": "DMY",
    "january": [
        "ngo",
        "ngɔn osú"
    ],
    "february": [
        "ngb",
        "ngɔn bɛ̌"
    ],
    "march": [
        "ngl",
        "ngɔn lála"
    ],
    "april": [
        "ngn",
        "ngɔn nyina"
    ],
    "may": [
        "ngt",
        "ngɔn tána"
    ],
    "june": [
        "ngs",
        "ngɔn saməna"
    ],
    "july": [
        "ngz",
        "ngɔn zamgbála"
    ],
    "august": [
        "ngm",
        "ngɔn mwom"
    ],
    "september": [
        "nge",
        "ngɔn ebulú"
    ],
    "october": [
        "nga",
        "ngɔn awóm"
    ],
    "november": [
        "ngad",
        "ngɔn awóm ai dziá"
    ],
    "december": [
        "ngab",
        "ngɔn awóm ai bɛ̌"
    ],
    "monday": [
        "mɔ́n",
        "mɔ́ndi"
    ],
    "tuesday": [
        "smb",
        "sɔ́ndɔ məlú mə́bɛ̌"
    ],
    "wednesday": [
        "sml",
        "sɔ́ndɔ məlú mə́lɛ́"
    ],
    "thursday": [
        "smn",
        "sɔ́ndɔ məlú mə́nyi"
    ],
    "friday": [
        "fúl",
        "fúladé"
    ],
    "saturday": [
        "sér",
        "séradé"
    ],
    "sunday": [
        "sɔ́n",
        "sɔ́ndɔ"
    ],
    "am": [
        "kíkíríg"
    ],
    "pm": [
        "ngəgógəle"
    ],
    "year": [
        "m̀bú"
    ],
    "month": [
        "ngɔn"
    ],
    "week": [
        "sɔ́ndɔ"
    ],
    "day": [
        "amǒs"
    ],
    "hour": [
        "awola"
    ],
    "minute": [
        "enútɛn"
    ],
    "second": [
        "akábəga"
    ],
    "relative-type": {
        "0 day ago": [
            "aná"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "angogé"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "okírí"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
