info = {
    "name": "smn",
    "date_order": "DMY",
    "january": [
        "uđiv",
        "uđđâivemáánu"
    ],
    "february": [
        "kuovâ",
        "kuovâmáánu"
    ],
    "march": [
        "njuhčâ",
        "njuhčâmáánu"
    ],
    "april": [
        "cuáŋui",
        "cuáŋuimáánu"
    ],
    "may": [
        "vyesi",
        "vyesimáánu"
    ],
    "june": [
        "kesi",
        "kesimáánu"
    ],
    "july": [
        "syeini",
        "syeinimáánu"
    ],
    "august": [
        "porge",
        "porgemáánu"
    ],
    "september": [
        "čohčâ",
        "čohčâmáánu"
    ],
    "october": [
        "roovvâd",
        "roovvâdmáánu"
    ],
    "november": [
        "skammâ",
        "skammâmáánu"
    ],
    "december": [
        "juovlâ",
        "juovlâmáánu"
    ],
    "monday": [
        "vuo",
        "vuossaargâ",
        "vuossargâ"
    ],
    "tuesday": [
        "maj",
        "majebaargâ",
        "majebargâ"
    ],
    "wednesday": [
        "kos",
        "koskoho",
        "koskokko"
    ],
    "thursday": [
        "tuo",
        "tuorâstuv",
        "tuorâstâh"
    ],
    "friday": [
        "vás",
        "vástuppeeivi",
        "vástuppeivi"
    ],
    "saturday": [
        "láv",
        "lávurduv",
        "lávurdâh"
    ],
    "sunday": [
        "pas",
        "pasepeeivi",
        "pasepeivi"
    ],
    "am": [
        "ip"
    ],
    "pm": [
        "ep"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
