info = {
    "name": "kab",
    "date_order": "DMY",
    "january": [
        "yen",
        "yennayer"
    ],
    "february": [
        "fur",
        "fuṛar"
    ],
    "march": [
        "meɣ",
        "meɣres"
    ],
    "april": [
        "yeb",
        "yebrir"
    ],
    "may": [
        "may",
        "mayyu"
    ],
    "june": [
        "yun",
        "yunyu"
    ],
    "july": [
        "yul",
        "yulyu"
    ],
    "august": [
        "ɣuc",
        "ɣuct"
    ],
    "september": [
        "cte",
        "ctembeṛ"
    ],
    "october": [
        "tub",
        "tubeṛ"
    ],
    "november": [
        "nun",
        "nunembeṛ"
    ],
    "december": [
        "duǧ",
        "duǧembeṛ"
    ],
    "monday": [
        "san",
        "sanass"
    ],
    "tuesday": [
        "kraḍ",
        "kraḍass"
    ],
    "wednesday": [
        "kuẓ",
        "kuẓass"
    ],
    "thursday": [
        "sam",
        "samass"
    ],
    "friday": [
        "sḍis",
        "sḍisass"
    ],
    "saturday": [
        "say",
        "sayass"
    ],
    "sunday": [
        "yan",
        "yanass"
    ],
    "am": [
        "n tufat"
    ],
    "pm": [
        "n tmeddit"
    ],
    "year": [
        "aseggas"
    ],
    "month": [
        "aggur"
    ],
    "week": [
        "ddurt"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tamert"
    ],
    "minute": [
        "tamrect"
    ],
    "second": [
        "tasint"
    ],
    "relative-type": {
        "0 day ago": [
            "ass-a"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "iḍelli"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "azekka"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
