info = {
    "name": "mk",
    "date_order": "DMY",
    "january": [
        "јан",
        "јануари"
    ],
    "february": [
        "фев",
        "февруари"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "април"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јун",
        "јуни"
    ],
    "july": [
        "јул",
        "јули"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "септ",
        "септември"
    ],
    "october": [
        "окт",
        "октомври"
    ],
    "november": [
        "ноем",
        "ноември"
    ],
    "december": [
        "дек",
        "декември"
    ],
    "monday": [
        "пон",
        "понеделник"
    ],
    "tuesday": [
        "вт",
        "вто",
        "вторник"
    ],
    "wednesday": [
        "сре",
        "среда"
    ],
    "thursday": [
        "чет",
        "четврток"
    ],
    "friday": [
        "пет",
        "петок"
    ],
    "saturday": [
        "саб",
        "сабота"
    ],
    "sunday": [
        "нед",
        "недела"
    ],
    "am": [
        "претпл",
        "претпладне"
    ],
    "pm": [
        "попл",
        "попладне"
    ],
    "year": [
        "год",
        "година"
    ],
    "month": [
        "мес",
        "месец"
    ],
    "week": [
        "недела",
        "сед"
    ],
    "day": [
        "ден"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "мин",
        "минута"
    ],
    "second": [
        "сек",
        "секунда"
    ],
    "relative-type": {
        "0 day ago": [
            "денес"
        ],
        "0 hour ago": [
            "часов"
        ],
        "0 minute ago": [
            "оваа минута"
        ],
        "0 month ago": [
            "овој месец"
        ],
        "0 second ago": [
            "сега"
        ],
        "0 week ago": [
            "оваа седмица"
        ],
        "0 year ago": [
            "оваа година"
        ],
        "1 day ago": [
            "вчера"
        ],
        "1 month ago": [
            "минатиот месец"
        ],
        "1 week ago": [
            "минатата седмица"
        ],
        "1 year ago": [
            "минатата година"
        ],
        "in 1 day": [
            "утре"
        ],
        "in 1 month": [
            "следниот месец"
        ],
        "in 1 week": [
            "следната седмица"
        ],
        "in 1 year": [
            "следната година"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "пред (\\d+[.,]?\\d*) ден",
            "пред (\\d+[.,]?\\d*) дена"
        ],
        "\\1 hour ago": [
            "пред (\\d+[.,]?\\d*) час",
            "пред (\\d+[.,]?\\d*) часа"
        ],
        "\\1 minute ago": [
            "пред (\\d+[.,]?\\d*) минута",
            "пред (\\d+[.,]?\\d*) минути"
        ],
        "\\1 month ago": [
            "пред (\\d+[.,]?\\d*) месец",
            "пред (\\d+[.,]?\\d*) месеци"
        ],
        "\\1 second ago": [
            "пред (\\d+[.,]?\\d*) секунда",
            "пред (\\d+[.,]?\\d*) секунди"
        ],
        "\\1 week ago": [
            "пред (\\d+[.,]?\\d*) седмица",
            "пред (\\d+[.,]?\\d*) седмици"
        ],
        "\\1 year ago": [
            "пред (\\d+[.,]?\\d*) година",
            "пред (\\d+[.,]?\\d*) години"
        ],
        "in \\1 day": [
            "за (\\d+[.,]?\\d*) ден",
            "за (\\d+[.,]?\\d*) дена"
        ],
        "in \\1 hour": [
            "за (\\d+[.,]?\\d*) час",
            "за (\\d+[.,]?\\d*) часа"
        ],
        "in \\1 minute": [
            "за (\\d+[.,]?\\d*) минута",
            "за (\\d+[.,]?\\d*) минути"
        ],
        "in \\1 month": [
            "за (\\d+[.,]?\\d*) месец",
            "за (\\d+[.,]?\\d*) месеци"
        ],
        "in \\1 second": [
            "за (\\d+[.,]?\\d*) секунда",
            "за (\\d+[.,]?\\d*) секунди"
        ],
        "in \\1 week": [
            "за (\\d+[.,]?\\d*) седмица",
            "за (\\d+[.,]?\\d*) седмици"
        ],
        "in \\1 year": [
            "за (\\d+[.,]?\\d*) година",
            "за (\\d+[.,]?\\d*) години"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
