info = {
    "name": "mn",
    "date_order": "YMD",
    "january": [
        "1-р сар",
        "нэгдүгээр сар"
    ],
    "february": [
        "2-р сар",
        "хоёрдугаар сар"
    ],
    "march": [
        "3-р сар",
        "гуравдугаар сар"
    ],
    "april": [
        "4-р сар",
        "дөрөвдүгээр сар"
    ],
    "may": [
        "5-р сар",
        "тавдугаар сар"
    ],
    "june": [
        "6-р сар",
        "зургадугаар сар"
    ],
    "july": [
        "7-р сар",
        "долдугаар сар"
    ],
    "august": [
        "8-р сар",
        "наймдугаар сар"
    ],
    "september": [
        "9-р сар",
        "есдүгээр сар"
    ],
    "october": [
        "10-р сар",
        "аравдугаар сар"
    ],
    "november": [
        "11-р сар",
        "арван нэгдүгээр сар"
    ],
    "december": [
        "12-р сар",
        "арван хоёрдугаар сар"
    ],
    "monday": [
        "да",
        "даваа"
    ],
    "tuesday": [
        "мя",
        "мягмар"
    ],
    "wednesday": [
        "лх",
        "лхагва"
    ],
    "thursday": [
        "пү",
        "пүрэв"
    ],
    "friday": [
        "ба",
        "баасан"
    ],
    "saturday": [
        "бя",
        "бямба"
    ],
    "sunday": [
        "ня",
        "ням"
    ],
    "am": [
        "үө"
    ],
    "pm": [
        "үх"
    ],
    "year": [
        "жил"
    ],
    "month": [
        "сар"
    ],
    "week": [
        "7х",
        "долоо хоног"
    ],
    "day": [
        "өдөр"
    ],
    "hour": [
        "ц",
        "цаг"
    ],
    "minute": [
        "мин",
        "минут"
    ],
    "second": [
        "сек",
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "өнөөдөр"
        ],
        "0 hour ago": [
            "энэ цаг"
        ],
        "0 minute ago": [
            "энэ минут"
        ],
        "0 month ago": [
            "энэ сар"
        ],
        "0 second ago": [
            "одоо"
        ],
        "0 week ago": [
            "энэ долоо хоног"
        ],
        "0 year ago": [
            "энэ жил"
        ],
        "1 day ago": [
            "өчигдөр"
        ],
        "1 month ago": [
            "өнгөрсөн сар"
        ],
        "1 week ago": [
            "өнгөрсөн долоо хоног"
        ],
        "1 year ago": [
            "өнгөрсөн жил"
        ],
        "in 1 day": [
            "маргааш"
        ],
        "in 1 month": [
            "ирэх сар"
        ],
        "in 1 week": [
            "ирэх долоо хоног"
        ],
        "in 1 year": [
            "ирэх жил"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) өдрийн өмнө"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ц өмнө",
            "(\\d+[.,]?\\d*) цагийн өмнө"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) мин өмнө",
            "(\\d+[.,]?\\d*) минутын өмнө"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) сарын өмнө"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) сек өмнө",
            "(\\d+[.,]?\\d*) секундын өмнө"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) 7х-ийн өмнө"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) жилийн өмнө"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) өдрийн дараа",
            "(\\d+[.,]?\\d*) өдөрт"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) ц дараа",
            "(\\d+[.,]?\\d*) цагийн дараа"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) мин дараа",
            "(\\d+[.,]?\\d*) минутын дараа"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) сарын дараа"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) сек дараа",
            "(\\d+[.,]?\\d*) секундын дараа"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) 7х-ийн дараа"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) жилийн дараа"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
