info = {
    "name": "dav",
    "date_order": "DMY",
    "january": [
        "imb",
        "mori ghwa imbiri"
    ],
    "february": [
        "kaw",
        "mori ghwa kawi"
    ],
    "march": [
        "kad",
        "mori ghwa kadadu"
    ],
    "april": [
        "kan",
        "mori ghwa kana"
    ],
    "may": [
        "kas",
        "mori ghwa kasanu"
    ],
    "june": [
        "kar",
        "mori ghwa karandadu"
    ],
    "july": [
        "mfu",
        "mori ghwa mfungade"
    ],
    "august": [
        "mori ghwa wunyanya",
        "wun"
    ],
    "september": [
        "ike",
        "mori ghwa ikenda"
    ],
    "october": [
        "iku",
        "mori ghwa ikumi"
    ],
    "november": [
        "imw",
        "mori ghwa ikumi na imweri"
    ],
    "december": [
        "iwi",
        "mori ghwa ikumi na iwi"
    ],
    "monday": [
        "jim",
        "kuramuka jimweri"
    ],
    "tuesday": [
        "kaw",
        "kuramuka kawi"
    ],
    "wednesday": [
        "kad",
        "kuramuka kadadu"
    ],
    "thursday": [
        "kan",
        "kuramuka kana"
    ],
    "friday": [
        "kas",
        "kuramuka kasanu"
    ],
    "saturday": [
        "kifula nguwo",
        "ngu"
    ],
    "sunday": [
        "ituku ja jumwa",
        "jum"
    ],
    "am": [
        "luma lwa k"
    ],
    "pm": [
        "luma lwa p"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mori"
    ],
    "week": [
        "juma"
    ],
    "day": [
        "ituku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "idime"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "iguo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kesho"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
