info = {
    "name": "teo",
    "date_order": "DMY",
    "january": [
        "orara",
        "rar"
    ],
    "february": [
        "muk",
        "omuk"
    ],
    "march": [
        "kwa",
        "okwamg'"
    ],
    "april": [
        "dun",
        "odung'el"
    ],
    "may": [
        "mar",
        "omaruk"
    ],
    "june": [
        "mod",
        "omodok'king'ol"
    ],
    "july": [
        "jol",
        "ojola"
    ],
    "august": [
        "opedel",
        "ped"
    ],
    "september": [
        "osokosokoma",
        "sok"
    ],
    "october": [
        "otibar",
        "tib"
    ],
    "november": [
        "lab",
        "olabor"
    ],
    "december": [
        "opoo",
        "poo"
    ],
    "monday": [
        "bar",
        "nakaebarasa"
    ],
    "tuesday": [
        "aar",
        "nakaare"
    ],
    "wednesday": [
        "nakauni",
        "uni"
    ],
    "thursday": [
        "nakaung'on",
        "ung"
    ],
    "friday": [
        "kan",
        "nakakany"
    ],
    "saturday": [
        "nakasabiti",
        "sab"
    ],
    "sunday": [
        "jum",
        "nakaejuma"
    ],
    "am": [
        "taparachu"
    ],
    "pm": [
        "ebongi"
    ],
    "year": [
        "ekan"
    ],
    "month": [
        "elap"
    ],
    "week": [
        "ewiki"
    ],
    "day": [
        "aparan"
    ],
    "hour": [
        "esaa"
    ],
    "minute": [
        "idakika"
    ],
    "second": [
        "isekonde"
    ],
    "relative-type": {
        "0 day ago": [
            "lolo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "jaan"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "moi"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "teo-KE": {
            "name": "teo-KE"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
