info = {
    "name": "ki",
    "date_order": "DMY",
    "january": [
        "jen",
        "njenuarĩ"
    ],
    "february": [
        "mwere wa kerĩ",
        "wkr"
    ],
    "march": [
        "mwere wa gatatũ",
        "wgt"
    ],
    "april": [
        "mwere wa kana",
        "wkn"
    ],
    "may": [
        "mwere wa gatano",
        "wtn"
    ],
    "june": [
        "mwere wa gatandatũ",
        "wtd"
    ],
    "july": [
        "mwere wa mũgwanja",
        "wmj"
    ],
    "august": [
        "mwere wa kanana",
        "wnn"
    ],
    "september": [
        "mwere wa kenda",
        "wkd"
    ],
    "october": [
        "mwere wa ikũmi",
        "wik"
    ],
    "november": [
        "mwere wa ikũmi na ũmwe",
        "wmw"
    ],
    "december": [
        "dit",
        "ndithemba"
    ],
    "monday": [
        "njumatatũ",
        "ntt"
    ],
    "tuesday": [
        "njumaine",
        "nmn"
    ],
    "wednesday": [
        "njumatana",
        "nmt"
    ],
    "thursday": [
        "aramithi",
        "art"
    ],
    "friday": [
        "njumaa",
        "nma"
    ],
    "saturday": [
        "njumamothi",
        "nmm"
    ],
    "sunday": [
        "kiumia",
        "kma"
    ],
    "am": [
        "kiroko"
    ],
    "pm": [
        "hwaĩ-inĩ"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mweri"
    ],
    "week": [
        "kiumia"
    ],
    "day": [
        "mũthenya"
    ],
    "hour": [
        "ithaa"
    ],
    "minute": [
        "ndagĩka"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "ũmũthĩ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ira"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "rũciũ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
