info = {
    "name": "mua",
    "date_order": "DMY",
    "january": [
        "flo",
        "fĩi loo"
    ],
    "february": [
        "cla",
        "cokcwaklaŋne"
    ],
    "march": [
        "cki",
        "cokcwaklii"
    ],
    "april": [
        "fmf",
        "fĩi marfoo"
    ],
    "may": [
        "mad",
        "madǝǝuutǝbijaŋ"
    ],
    "june": [
        "mamǝŋgwãafahbii",
        "mbi"
    ],
    "july": [
        "mamǝŋgwãalii",
        "mli"
    ],
    "august": [
        "madǝmbii",
        "mam"
    ],
    "september": [
        "fde",
        "fĩi dǝɓlii"
    ],
    "october": [
        "fmu",
        "fĩi mundaŋ"
    ],
    "november": [
        "fgw",
        "fĩi gwahlle"
    ],
    "december": [
        "fyu",
        "fĩi yuru"
    ],
    "monday": [
        "cla",
        "comlaaɗii"
    ],
    "tuesday": [
        "comzyiiɗii",
        "czi"
    ],
    "wednesday": [
        "cko",
        "comkolle"
    ],
    "thursday": [
        "cka",
        "comkaldǝɓlii"
    ],
    "friday": [
        "cga",
        "comgaisuu"
    ],
    "saturday": [
        "comzyeɓsuu",
        "cze"
    ],
    "sunday": [
        "com'yakke",
        "cya"
    ],
    "am": [
        "comme"
    ],
    "pm": [
        "lilli"
    ],
    "year": [
        "syii"
    ],
    "month": [
        "fĩi"
    ],
    "week": [
        "luma"
    ],
    "day": [
        "zah'nane/ comme"
    ],
    "hour": [
        "cok comme"
    ],
    "minute": [
        "cok comme ma laŋne"
    ],
    "second": [
        "cok comme ma laŋ tǝ biŋ"
    ],
    "relative-type": {
        "0 day ago": [
            "tǝ'nahko"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "tǝsoo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tǝ'nane"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
