info = {
    "name": "cgg",
    "date_order": "DMY",
    "january": [
        "kbz",
        "okwokubanza"
    ],
    "february": [
        "kbr",
        "okwakabiri"
    ],
    "march": [
        "kst",
        "okwakashatu"
    ],
    "april": [
        "kkn",
        "okwakana"
    ],
    "may": [
        "ktn",
        "okwakataana"
    ],
    "june": [
        "kmk",
        "okwamukaaga"
    ],
    "july": [
        "kms",
        "okwamushanju"
    ],
    "august": [
        "kmn",
        "okwamunaana"
    ],
    "september": [
        "kmw",
        "okwamwenda"
    ],
    "october": [
        "kkm",
        "okwaikumi"
    ],
    "november": [
        "knk",
        "okwaikumi na kumwe"
    ],
    "december": [
        "knb",
        "okwaikumi na ibiri"
    ],
    "monday": [
        "ork",
        "orwokubanza"
    ],
    "tuesday": [
        "okb",
        "orwakabiri"
    ],
    "wednesday": [
        "oks",
        "orwakashatu"
    ],
    "thursday": [
        "okn",
        "orwakana"
    ],
    "friday": [
        "okt",
        "orwakataano"
    ],
    "saturday": [
        "omk",
        "orwamukaaga"
    ],
    "sunday": [
        "san",
        "sande"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omwezi"
    ],
    "week": [
        "esande"
    ],
    "day": [
        "eizooba"
    ],
    "hour": [
        "shaaha"
    ],
    "minute": [
        "edakiika"
    ],
    "second": [
        "obucweka/esekendi"
    ],
    "relative-type": {
        "0 day ago": [
            "erizooba"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "nyomwabazyo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "nyenkyakare"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
