info = {
    "name": "sn",
    "date_order": "YMD",
    "january": [
        "ndi",
        "ndira"
    ],
    "february": [
        "kuk",
        "kukadzi"
    ],
    "march": [
        "kur",
        "kurume"
    ],
    "april": [
        "kub",
        "kubvumbi"
    ],
    "may": [
        "chivabvu",
        "chv"
    ],
    "june": [
        "chikumi",
        "chk"
    ],
    "july": [
        "chg",
        "chikunguru"
    ],
    "august": [
        "nya",
        "nyamavhuvhu"
    ],
    "september": [
        "gun",
        "gunyana"
    ],
    "october": [
        "gum",
        "gumiguru"
    ],
    "november": [
        "mbu",
        "mbudzi"
    ],
    "december": [
        "zvi",
        "zvita"
    ],
    "monday": [
        "muv",
        "muvhuro"
    ],
    "tuesday": [
        "chipiri",
        "chp"
    ],
    "wednesday": [
        "chitatu",
        "cht"
    ],
    "thursday": [
        "china",
        "chn"
    ],
    "friday": [
        "chishanu",
        "chs"
    ],
    "saturday": [
        "mug",
        "mugovera"
    ],
    "sunday": [
        "svo",
        "svondo"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "gore"
    ],
    "month": [
        "mwedzi"
    ],
    "week": [
        "vhiki"
    ],
    "day": [
        "zuva"
    ],
    "hour": [
        "awa"
    ],
    "minute": [
        "mineti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "0 day ago": [
            "nhasi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "nezuro"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "mangwana"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
