info = {
    "name": "eu",
    "date_order": "YMD",
    "january": [
        "urt",
        "urtarrila"
    ],
    "february": [
        "ots",
        "otsaila"
    ],
    "march": [
        "mar",
        "martxoa"
    ],
    "april": [
        "api",
        "apirila"
    ],
    "may": [
        "mai",
        "maiatza"
    ],
    "june": [
        "eka",
        "ekaina"
    ],
    "july": [
        "uzt",
        "uztaila"
    ],
    "august": [
        "abu",
        "abuztua"
    ],
    "september": [
        "ira",
        "iraila"
    ],
    "october": [
        "urr",
        "urria"
    ],
    "november": [
        "aza",
        "azaroa"
    ],
    "december": [
        "abe",
        "abendua"
    ],
    "monday": [
        "al",
        "astelehena"
    ],
    "tuesday": [
        "ar",
        "asteartea"
    ],
    "wednesday": [
        "asteazkena",
        "az"
    ],
    "thursday": [
        "og",
        "osteguna"
    ],
    "friday": [
        "or",
        "ostirala"
    ],
    "saturday": [
        "larunbata",
        "lr"
    ],
    "sunday": [
        "ig",
        "igandea"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "urtea"
    ],
    "month": [
        "hil",
        "hilabetea"
    ],
    "week": [
        "ast",
        "astea"
    ],
    "day": [
        "eg",
        "eguna"
    ],
    "hour": [
        "h",
        "ordua"
    ],
    "minute": [
        "min",
        "minutua"
    ],
    "second": [
        "s",
        "segundoa"
    ],
    "relative-type": {
        "0 day ago": [
            "gaur"
        ],
        "0 hour ago": [
            "ordu honetan"
        ],
        "0 minute ago": [
            "minutu honetan"
        ],
        "0 month ago": [
            "hilabete hau"
        ],
        "0 second ago": [
            "orain"
        ],
        "0 week ago": [
            "aste hau"
        ],
        "0 year ago": [
            "aurten"
        ],
        "1 day ago": [
            "atzo"
        ],
        "1 month ago": [
            "aurreko hilabetea"
        ],
        "1 week ago": [
            "aurreko astea"
        ],
        "1 year ago": [
            "aurreko urtea"
        ],
        "in 1 day": [
            "bihar"
        ],
        "in 1 month": [
            "hurrengo hilabetea"
        ],
        "in 1 week": [
            "hurrengo astea"
        ],
        "in 1 year": [
            "hurrengo urtea"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "duela (\\d+[.,]?\\d*) egun"
        ],
        "\\1 hour ago": [
            "duela (\\d+[.,]?\\d*) ordu"
        ],
        "\\1 minute ago": [
            "duela (\\d+[.,]?\\d*) minutu"
        ],
        "\\1 month ago": [
            "duela (\\d+[.,]?\\d*) hilabete"
        ],
        "\\1 second ago": [
            "duela (\\d+[.,]?\\d*) segundo"
        ],
        "\\1 week ago": [
            "duela (\\d+[.,]?\\d*) aste"
        ],
        "\\1 year ago": [
            "duela (\\d+[.,]?\\d*) urte"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) egun barru"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) ordu barru"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) minutu barru"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) hilabete barru"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) segundo barru"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) aste barru"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) urte barru"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
