info = {
    "name": "ii",
    "date_order": "YMD",
    "january": [
        "ꋍꆪ"
    ],
    "february": [
        "ꑍꆪ"
    ],
    "march": [
        "ꌕꆪ"
    ],
    "april": [
        "ꇖꆪ"
    ],
    "may": [
        "ꉬꆪ"
    ],
    "june": [
        "ꃘꆪ"
    ],
    "july": [
        "ꏃꆪ"
    ],
    "august": [
        "ꉆꆪ"
    ],
    "september": [
        "ꈬꆪ"
    ],
    "october": [
        "ꊰꆪ"
    ],
    "november": [
        "ꊰꊪꆪ"
    ],
    "december": [
        "ꊰꑋꆪ"
    ],
    "monday": [
        "ꆏꊂꋍ",
        "ꆏꋍ"
    ],
    "tuesday": [
        "ꆏꊂꑍ",
        "ꆏꑍ"
    ],
    "wednesday": [
        "ꆏꊂꌕ",
        "ꆏꌕ"
    ],
    "thursday": [
        "ꆏꇖ",
        "ꆏꊂꇖ"
    ],
    "friday": [
        "ꆏꉬ",
        "ꆏꊂꉬ"
    ],
    "saturday": [
        "ꆏꃘ",
        "ꆏꊂꃘ"
    ],
    "sunday": [
        "ꑭꆏ",
        "ꑭꆏꑍ"
    ],
    "am": [
        "ꎸꄑ"
    ],
    "pm": [
        "ꁯꋒ"
    ],
    "year": [
        "ꈎ"
    ],
    "month": [
        "ꆪ"
    ],
    "week": [
        "ꑭꆏ"
    ],
    "day": [
        "ꑍ"
    ],
    "hour": [
        "ꄮꈉ"
    ],
    "minute": [
        "ꃏ"
    ],
    "second": [
        "ꇙ"
    ],
    "relative-type": {
        "0 day ago": [
            "ꀃꑍ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ꀋꅔꉈ"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ꃆꏂꑍ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
