info = {
    "name": "sg",
    "date_order": "DMY",
    "january": [
        "nye",
        "nyenye"
    ],
    "february": [
        "ful",
        "fulundïgi"
    ],
    "march": [
        "mbä",
        "mbängü"
    ],
    "april": [
        "ngu",
        "ngubùe"
    ],
    "may": [
        "bêl",
        "bêläwü"
    ],
    "june": [
        "fön",
        "föndo"
    ],
    "july": [
        "len",
        "lengua"
    ],
    "august": [
        "kük",
        "kükürü"
    ],
    "september": [
        "mvu",
        "mvuka"
    ],
    "october": [
        "ngb",
        "ngberere"
    ],
    "november": [
        "nab",
        "nabändüru"
    ],
    "december": [
        "kak",
        "kakauka"
    ],
    "monday": [
        "bk2",
        "bïkua-ûse"
    ],
    "tuesday": [
        "bk3",
        "bïkua-ptâ"
    ],
    "wednesday": [
        "bk4",
        "bïkua-usïö"
    ],
    "thursday": [
        "bk5",
        "bïkua-okü"
    ],
    "friday": [
        "lâp",
        "lâpôsö"
    ],
    "saturday": [
        "lây",
        "lâyenga"
    ],
    "sunday": [
        "bikua-ôko",
        "bk1"
    ],
    "am": [
        "nd"
    ],
    "pm": [
        "lk"
    ],
    "year": [
        "ngû"
    ],
    "month": [
        "nze"
    ],
    "week": [
        "dimâsi"
    ],
    "day": [
        "lâ"
    ],
    "hour": [
        "ngbonga"
    ],
    "minute": [
        "ndurü ngbonga"
    ],
    "second": [
        "nzîna ngbonga"
    ],
    "relative-type": {
        "0 day ago": [
            "lâsô"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "bîrï"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kêkerêke"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
