info = {
    "name": "yo",
    "date_order": "DMY",
    "january": [
        "oṣù ṣẹ́rẹ́",
        "ṣẹ́rẹ́"
    ],
    "february": [
        "oṣù èrèlè",
        "èrèlè"
    ],
    "march": [
        "oṣù ẹrẹ̀nà",
        "ẹrẹ̀nà"
    ],
    "april": [
        "oṣù ìgbé",
        "ìgbé"
    ],
    "may": [
        "oṣù ẹ̀bibi",
        "ẹ̀bibi"
    ],
    "june": [
        "oṣù òkúdu",
        "òkúdu"
    ],
    "july": [
        "agẹmọ",
        "oṣù agẹmọ"
    ],
    "august": [
        "oṣù ògún",
        "ògún"
    ],
    "september": [
        "owewe",
        "oṣù owewe"
    ],
    "october": [
        "oṣù ọ̀wàrà",
        "ọ̀wàrà"
    ],
    "november": [
        "bélú",
        "oṣù bélú"
    ],
    "december": [
        "oṣù ọ̀pẹ̀",
        "ọ̀pẹ̀"
    ],
    "monday": [
        "ajé",
        "ọjọ́ ajé"
    ],
    "tuesday": [
        "ìsẹ́gun",
        "ọjọ́ ìsẹ́gun"
    ],
    "wednesday": [
        "ọjọ́rú"
    ],
    "thursday": [
        "ọjọ́bọ"
    ],
    "friday": [
        "ẹtì",
        "ọjọ́ ẹtì"
    ],
    "saturday": [
        "àbámẹ́ta",
        "ọjọ́ àbámẹ́ta"
    ],
    "sunday": [
        "àìkú",
        "ọjọ́ àìkú"
    ],
    "am": [
        "àárọ̀"
    ],
    "pm": [
        "ọ̀sán"
    ],
    "year": [
        "ọdún"
    ],
    "month": [
        "osù"
    ],
    "week": [
        "ọ̀sè"
    ],
    "day": [
        "ọjọ́"
    ],
    "hour": [
        "wákàtí"
    ],
    "minute": [
        "ìsẹ́jú"
    ],
    "second": [
        "ìsẹ́jú ààyá"
    ],
    "relative-type": {
        "0 day ago": [
            "òní"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "àná"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ọ̀la"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "yo-BJ": {
            "name": "yo-BJ",
            "january": [
                "oshù shɛ́rɛ́",
                "shɛ́rɛ́"
            ],
            "february": [
                "oshù èrèlè"
            ],
            "march": [
                "oshù ɛrɛ̀nà",
                "ɛrɛ̀nà"
            ],
            "april": [
                "oshù ìgbé"
            ],
            "may": [
                "oshù ɛ̀bibi",
                "ɛ̀bibi"
            ],
            "june": [
                "oshù òkúdu"
            ],
            "july": [
                "agɛmɔ",
                "oshù agɛmɔ"
            ],
            "august": [
                "oshù ògún"
            ],
            "september": [
                "oshù owewe"
            ],
            "october": [
                "oshù ɔ̀wàrà",
                "ɔ̀wàrà"
            ],
            "november": [
                "oshù bélú"
            ],
            "december": [
                "oshù ɔ̀pɛ̀",
                "ɔ̀pɛ̀"
            ],
            "monday": [
                "ɔjɔ́ ajé"
            ],
            "tuesday": [
                "ìsɛ́gun",
                "ɔjɔ́ ìsɛ́gun"
            ],
            "wednesday": [
                "ɔjɔ́rú"
            ],
            "thursday": [
                "ɔjɔ́bɔ"
            ],
            "friday": [
                "ɔjɔ́ ɛtì",
                "ɛtì"
            ],
            "saturday": [
                "àbámɛ́ta",
                "ɔjɔ́ àbámɛ́ta"
            ],
            "sunday": [
                "ɔjɔ́ àìkú"
            ],
            "am": [
                "àárɔ̀"
            ],
            "pm": [
                "ɔ̀sán"
            ],
            "year": [
                "ɔdún"
            ],
            "week": [
                "ɔ̀sè"
            ],
            "day": [
                "ɔjɔ́"
            ],
            "minute": [
                "ìsɛ́jú"
            ],
            "second": [
                "ìsɛ́jú ààyá"
            ],
            "relative-type": {
                "in 1 day": [
                    "ɔ̀la"
                ]
            }
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
