info = {
    "name": "rof",
    "date_order": "DMY",
    "january": [
        "mweri wa kwanza"
    ],
    "february": [
        "mweri wa kaili"
    ],
    "march": [
        "mweri wa katatu"
    ],
    "april": [
        "mweri wa kaana"
    ],
    "may": [
        "mweri wa tanu"
    ],
    "june": [
        "mweri wa sita"
    ],
    "july": [
        "mweri wa saba"
    ],
    "august": [
        "mweri wa nane"
    ],
    "september": [
        "mweri wa tisa"
    ],
    "october": [
        "mweri wa ikumi"
    ],
    "november": [
        "mweri wa ikumi na moja"
    ],
    "december": [
        "mweri wa ikumi na mbili"
    ],
    "monday": [
        "ijt",
        "ijumatatu"
    ],
    "tuesday": [
        "ijn",
        "ijumanne"
    ],
    "wednesday": [
        "ijtn",
        "ijumatano"
    ],
    "thursday": [
        "alh",
        "alhamisi"
    ],
    "friday": [
        "iju",
        "ijumaa"
    ],
    "saturday": [
        "ijm",
        "ijumamosi"
    ],
    "sunday": [
        "ijp",
        "ijumapili"
    ],
    "am": [
        "kang'ama"
    ],
    "pm": [
        "kingoto"
    ],
    "year": [
        "muaka"
    ],
    "month": [
        "mweri"
    ],
    "week": [
        "iwiki"
    ],
    "day": [
        "mfiri"
    ],
    "hour": [
        "isaa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "linu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "hiyo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ng'ama"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
